@@ -82,7 +82,7 @@ class Exceptions:
 
 class SecretsManagerClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html)
     """
 
@@ -98,7 +98,7 @@ class SecretsManagerClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#can_paginate)
         """
 
@@ -107,7 +107,7 @@ class SecretsManagerClient(BaseClient):
         Disables automatic scheduled rotation and cancels the rotation of a secret if
         currently in progress.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#cancel_rotate_secret)
         """
 
@@ -115,19 +115,19 @@ class SecretsManagerClient(BaseClient):
         self,
         *,
         Name: str,
-        ClientRequestToken: str = None,
-        Description: str = None,
-        KmsKeyId: str = None,
-        SecretBinary: Union[bytes, IO[bytes], StreamingBody] = None,
-        SecretString: str = None,
-        Tags: Sequence["TagTypeDef"] = None,
-        AddReplicaRegions: Sequence["ReplicaRegionTypeTypeDef"] = None,
-        ForceOverwriteReplicaSecret: bool = None
+        ClientRequestToken: str = ...,
+        Description: str = ...,
+        KmsKeyId: str = ...,
+        SecretBinary: Union[bytes, IO[bytes], StreamingBody] = ...,
+        SecretString: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...,
+        AddReplicaRegions: Sequence["ReplicaRegionTypeTypeDef"] = ...,
+        ForceOverwriteReplicaSecret: bool = ...
     ) -> CreateSecretResponseTypeDef:
         """
         Creates a new secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#create_secret)
         """
 
@@ -135,7 +135,7 @@ class SecretsManagerClient(BaseClient):
         """
         Deletes the resource-based permission policy attached to the secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#delete_resource_policy)
         """
 
@@ -143,13 +143,13 @@ class SecretsManagerClient(BaseClient):
         self,
         *,
         SecretId: str,
-        RecoveryWindowInDays: int = None,
-        ForceDeleteWithoutRecovery: bool = None
+        RecoveryWindowInDays: int = ...,
+        ForceDeleteWithoutRecovery: bool = ...
     ) -> DeleteSecretResponseTypeDef:
         """
         Deletes an entire secret and all of the versions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#delete_secret)
         """
 
@@ -157,40 +157,40 @@ class SecretsManagerClient(BaseClient):
         """
         Retrieves the details of a secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#describe_secret)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#generate_presigned_url)
         """
 
     def get_random_password(
         self,
         *,
-        PasswordLength: int = None,
-        ExcludeCharacters: str = None,
-        ExcludeNumbers: bool = None,
-        ExcludePunctuation: bool = None,
-        ExcludeUppercase: bool = None,
-        ExcludeLowercase: bool = None,
-        IncludeSpace: bool = None,
-        RequireEachIncludedType: bool = None
+        PasswordLength: int = ...,
+        ExcludeCharacters: str = ...,
+        ExcludeNumbers: bool = ...,
+        ExcludePunctuation: bool = ...,
+        ExcludeUppercase: bool = ...,
+        ExcludeLowercase: bool = ...,
+        IncludeSpace: bool = ...,
+        RequireEachIncludedType: bool = ...
     ) -> GetRandomPasswordResponseTypeDef:
         """
         Generates a random password of the specified complexity.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#get_random_password)
         """
 
@@ -199,18 +199,18 @@ class SecretsManagerClient(BaseClient):
         Retrieves the JSON text of the resource-based policy document attached to the
         specified secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#get_resource_policy)
         """
 
     def get_secret_value(
-        self, *, SecretId: str, VersionId: str = None, VersionStage: str = None
+        self, *, SecretId: str, VersionId: str = ..., VersionStage: str = ...
     ) -> GetSecretValueResponseTypeDef:
         """
         Retrieves the contents of the encrypted fields `SecretString` or `SecretBinary`
         from the specified version of a secret, whichever contains content.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#get_secret_value)
         """
 
@@ -218,41 +218,41 @@ class SecretsManagerClient(BaseClient):
         self,
         *,
         SecretId: str,
-        MaxResults: int = None,
-        NextToken: str = None,
-        IncludeDeprecated: bool = None
+        MaxResults: int = ...,
+        NextToken: str = ...,
+        IncludeDeprecated: bool = ...
     ) -> ListSecretVersionIdsResponseTypeDef:
         """
         Lists all of the versions attached to the specified secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#list_secret_version_ids)
         """
 
     def list_secrets(
         self,
         *,
-        MaxResults: int = None,
-        NextToken: str = None,
-        Filters: Sequence["FilterTypeDef"] = None,
-        SortOrder: SortOrderTypeType = None
+        MaxResults: int = ...,
+        NextToken: str = ...,
+        Filters: Sequence["FilterTypeDef"] = ...,
+        SortOrder: SortOrderTypeType = ...
     ) -> ListSecretsResponseTypeDef:
         """
         Lists all of the secrets that are stored by Secrets Manager in the Amazon Web
         Services account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#list_secrets)
         """
 
     def put_resource_policy(
-        self, *, SecretId: str, ResourcePolicy: str, BlockPublicPolicy: bool = None
+        self, *, SecretId: str, ResourcePolicy: str, BlockPublicPolicy: bool = ...
     ) -> PutResourcePolicyResponseTypeDef:
         """
         Attaches the contents of the specified resource-based permission policy to a
         secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#put_resource_policy)
         """
 
@@ -260,15 +260,15 @@ class SecretsManagerClient(BaseClient):
         self,
         *,
         SecretId: str,
-        ClientRequestToken: str = None,
-        SecretBinary: Union[bytes, IO[bytes], StreamingBody] = None,
-        SecretString: str = None,
-        VersionStages: Sequence[str] = None
+        ClientRequestToken: str = ...,
+        SecretBinary: Union[bytes, IO[bytes], StreamingBody] = ...,
+        SecretString: str = ...,
+        VersionStages: Sequence[str] = ...
     ) -> PutSecretValueResponseTypeDef:
         """
         Stores a new encrypted secret value in the specified secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#put_secret_value)
         """
 
@@ -278,7 +278,7 @@ class SecretsManagerClient(BaseClient):
         """
         Remove regions from replication.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.remove_regions_from_replication)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.remove_regions_from_replication)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#remove_regions_from_replication)
         """
 
@@ -287,13 +287,13 @@ class SecretsManagerClient(BaseClient):
         *,
         SecretId: str,
         AddReplicaRegions: Sequence["ReplicaRegionTypeTypeDef"],
-        ForceOverwriteReplicaSecret: bool = None
+        ForceOverwriteReplicaSecret: bool = ...
     ) -> ReplicateSecretToRegionsResponseTypeDef:
         """
         Converts an existing secret to a multi-Region secret and begins replication the
         secret to a list of new regions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.replicate_secret_to_regions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.replicate_secret_to_regions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#replicate_secret_to_regions)
         """
 
@@ -302,7 +302,7 @@ class SecretsManagerClient(BaseClient):
         Cancels the scheduled deletion of a secret by removing the `DeletedDate` time
         stamp.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#restore_secret)
         """
 
@@ -310,14 +310,14 @@ class SecretsManagerClient(BaseClient):
         self,
         *,
         SecretId: str,
-        ClientRequestToken: str = None,
-        RotationLambdaARN: str = None,
-        RotationRules: "RotationRulesTypeTypeDef" = None
+        ClientRequestToken: str = ...,
+        RotationLambdaARN: str = ...,
+        RotationRules: "RotationRulesTypeTypeDef" = ...
     ) -> RotateSecretResponseTypeDef:
         """
         Configures and starts the asynchronous process of rotating this secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#rotate_secret)
         """
 
@@ -328,7 +328,7 @@ class SecretsManagerClient(BaseClient):
         Removes the secret from replication and promotes the secret to a regional secret
         in the replica Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.stop_replication_to_replica)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.stop_replication_to_replica)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#stop_replication_to_replica)
         """
 
@@ -337,7 +337,7 @@ class SecretsManagerClient(BaseClient):
         Attaches one or more tags, each consisting of a key name and a value, to the
         specified secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#tag_resource)
         """
 
@@ -345,7 +345,7 @@ class SecretsManagerClient(BaseClient):
         """
         Removes one or more tags from the specified secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#untag_resource)
         """
 
@@ -353,16 +353,16 @@ class SecretsManagerClient(BaseClient):
         self,
         *,
         SecretId: str,
-        ClientRequestToken: str = None,
-        Description: str = None,
-        KmsKeyId: str = None,
-        SecretBinary: Union[bytes, IO[bytes], StreamingBody] = None,
-        SecretString: str = None
+        ClientRequestToken: str = ...,
+        Description: str = ...,
+        KmsKeyId: str = ...,
+        SecretBinary: Union[bytes, IO[bytes], StreamingBody] = ...,
+        SecretString: str = ...
     ) -> UpdateSecretResponseTypeDef:
         """
         Modifies many of the details of the specified secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#update_secret)
         """
 
@@ -371,29 +371,29 @@ class SecretsManagerClient(BaseClient):
         *,
         SecretId: str,
         VersionStage: str,
-        RemoveFromVersionId: str = None,
-        MoveToVersionId: str = None
+        RemoveFromVersionId: str = ...,
+        MoveToVersionId: str = ...
     ) -> UpdateSecretVersionStageResponseTypeDef:
         """
         Modifies the staging labels attached to a version of a secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#update_secret_version_stage)
         """
 
     def validate_resource_policy(
-        self, *, ResourcePolicy: str, SecretId: str = None
+        self, *, ResourcePolicy: str, SecretId: str = ...
     ) -> ValidateResourcePolicyResponseTypeDef:
         """
         Validates that the resource policy does not grant a wide range of IAM principals
         access to your secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Client.validate_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Client.validate_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#validate_resource_policy)
         """
 
     def get_paginator(self, operation_name: Literal["list_secrets"]) -> ListSecretsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
         """
