@@ -37,6 +37,7 @@ SortOrderTypeType = Literal["asc", "desc"]
 StatusTypeType = Literal["Failed", "InProgress", "InSync"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -69,6 +70,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
