@@ -41,18 +41,18 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListSecretsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
     """
 
     def paginate(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = None,
-        SortOrder: SortOrderTypeType = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        Filters: Sequence["FilterTypeDef"] = ...,
+        SortOrder: SortOrderTypeType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListSecretsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
         """
